@@ -90,32 +90,32 @@
 <context>
     <name>BrowseListWindow</name>
     <message>
-        <location filename="../../src/maemo5/browselistwindow.cpp" line="77"/>
+        <location filename="../../src/maemo5/browselistwindow.cpp" line="76"/>
         <source>Stations by genre</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/browselistwindow.cpp" line="78"/>
+        <location filename="../../src/maemo5/browselistwindow.cpp" line="77"/>
         <source>No genres found</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/browselistwindow.cpp" line="83"/>
+        <location filename="../../src/maemo5/browselistwindow.cpp" line="82"/>
         <source>Stations by country</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/browselistwindow.cpp" line="84"/>
+        <location filename="../../src/maemo5/browselistwindow.cpp" line="83"/>
         <source>No countries found</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/browselistwindow.cpp" line="89"/>
+        <location filename="../../src/maemo5/browselistwindow.cpp" line="88"/>
         <source>Stations by language</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../src/maemo5/browselistwindow.cpp" line="90"/>
+        <location filename="../../src/maemo5/browselistwindow.cpp" line="89"/>
         <source>No languages found</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1391,6 +1391,11 @@
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../../src/maemo5/stationlistwindow.cpp" line="46"/>
+        <source>No stations found</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../../src/maemo5/stationlistwindow.cpp" line="48"/>
         <source>Stations</source>
